@@ -1,5 +1,5 @@
 from django.contrib import admin
-from samklang_payment.models import Donation, DonationCampaign, PaymentSite
+from samklang_payment.models import Donation, DonationCampaign, PaymentSite, DonationSuggestion
 
 # will work when 1.4 is out
 #class CapturedStatusfilter(SimpleListFilter):
@@ -28,3 +28,4 @@ class DonationAdmin(admin.ModelAdmin):
 admin.site.register(Donation, DonationAdmin)
 admin.site.register(PaymentSite)
 admin.site.register(DonationCampaign)
+admin.site.register(DonationSuggestion)
